"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.timestamp_pb2
import typing
import yandex.cloud.logging.v1.log_entry_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Export(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    ID_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    CLOUD_ID_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    GROUP_ID_FIELD_NUMBER: builtins.int
    SINK_ID_FIELD_NUMBER: builtins.int
    PARAMS_FIELD_NUMBER: builtins.int
    id: builtins.str
    """Export ID."""
    folder_id: builtins.str
    """Export folder ID."""
    cloud_id: builtins.str
    """Export cloud ID."""
    name: builtins.str
    """Export name."""
    description: builtins.str
    """Export description."""
    group_id: builtins.str
    """Group logs are exported from."""
    sink_id: builtins.str
    """Sink logs are exported to."""
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Export creation time."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Export lables."""

    @property
    def params(self) -> global___ExportParams:
        """Parameters of logs filtration."""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        folder_id: builtins.str = ...,
        cloud_id: builtins.str = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        group_id: builtins.str = ...,
        sink_id: builtins.str = ...,
        params: global___ExportParams | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["created_at", b"created_at", "params", b"params"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["cloud_id", b"cloud_id", "created_at", b"created_at", "description", b"description", "folder_id", b"folder_id", "group_id", b"group_id", "id", b"id", "labels", b"labels", "name", b"name", "params", b"params", "sink_id", b"sink_id"]) -> None: ...

global___Export = Export

@typing.final
class ExportParams(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_TYPES_FIELD_NUMBER: builtins.int
    RESOURCE_IDS_FIELD_NUMBER: builtins.int
    STREAM_NAMES_FIELD_NUMBER: builtins.int
    LEVELS_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    filter: builtins.str
    @property
    def resource_types(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def resource_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def stream_names(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def levels(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[yandex.cloud.logging.v1.log_entry_pb2.LogLevel.Level.ValueType]: ...
    def __init__(
        self,
        *,
        resource_types: collections.abc.Iterable[builtins.str] | None = ...,
        resource_ids: collections.abc.Iterable[builtins.str] | None = ...,
        stream_names: collections.abc.Iterable[builtins.str] | None = ...,
        levels: collections.abc.Iterable[yandex.cloud.logging.v1.log_entry_pb2.LogLevel.Level.ValueType] | None = ...,
        filter: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["filter", b"filter", "levels", b"levels", "resource_ids", b"resource_ids", "resource_types", b"resource_types", "stream_names", b"stream_names"]) -> None: ...

global___ExportParams = ExportParams



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/ai/assistants/v1/searchindex/search_index_file_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud.ai.assistants.v1.searchindex import search_index_file_pb2 as yandex_dot_cloud_dot_ai_dot_assistants_dot_v1_dot_searchindex_dot_search__index__file__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nIyandex/cloud/ai/assistants/v1/searchindex/search_index_file_service.proto\x12)yandex.cloud.ai.assistants.v1.searchindex\x1a\x41yandex/cloud/ai/assistants/v1/searchindex/search_index_file.proto\x1a\x1dyandex/cloud/validation.proto\x1a\x1cgoogle/api/annotations.proto\"Q\n\x19GetSearchIndexFileRequest\x12\x15\n\x07\x66ile_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x1d\n\x0fsearch_index_id\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\"c\n\x1bListSearchIndexFilesRequest\x12\x1d\n\x0fsearch_index_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x11\n\tpage_size\x18\x02 \x01(\x03\x12\x12\n\npage_token\x18\x03 \x01(\t\"\x82\x01\n\x1cListSearchIndexFilesResponse\x12I\n\x05\x66iles\x18\x01 \x03(\x0b\x32:.yandex.cloud.ai.assistants.v1.searchindex.SearchIndexFile\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t2\xba\x03\n\x16SearchIndexFileService\x12\xcb\x01\n\x03Get\x12\x44.yandex.cloud.ai.assistants.v1.searchindex.GetSearchIndexFileRequest\x1a:.yandex.cloud.ai.assistants.v1.searchindex.SearchIndexFile\"B\x82\xd3\xe4\x93\x02<\x12:/assistants/v1/searchIndexFile/{search_index_id}/{file_id}\x12\xd1\x01\n\x04List\x12\x46.yandex.cloud.ai.assistants.v1.searchindex.ListSearchIndexFilesRequest\x1aG.yandex.cloud.ai.assistants.v1.searchindex.ListSearchIndexFilesResponse\"8\x82\xd3\xe4\x93\x02\x32\x12\x30/assistants/v1/searchIndexFile/{search_index_id}B\x8a\x01\n-yandex.cloud.api.ai.assistants.v1.searchindexZYgithub.com/yandex-cloud/go-genproto/yandex/cloud/ai/assistants/v1/searchindex;searchindexb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.ai.assistants.v1.searchindex.search_index_file_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n-yandex.cloud.api.ai.assistants.v1.searchindexZYgithub.com/yandex-cloud/go-genproto/yandex/cloud/ai/assistants/v1/searchindex;searchindex'
  _GETSEARCHINDEXFILEREQUEST.fields_by_name['file_id']._options = None
  _GETSEARCHINDEXFILEREQUEST.fields_by_name['file_id']._serialized_options = b'\350\3071\001'
  _GETSEARCHINDEXFILEREQUEST.fields_by_name['search_index_id']._options = None
  _GETSEARCHINDEXFILEREQUEST.fields_by_name['search_index_id']._serialized_options = b'\350\3071\001'
  _LISTSEARCHINDEXFILESREQUEST.fields_by_name['search_index_id']._options = None
  _LISTSEARCHINDEXFILESREQUEST.fields_by_name['search_index_id']._serialized_options = b'\350\3071\001'
  _SEARCHINDEXFILESERVICE.methods_by_name['Get']._options = None
  _SEARCHINDEXFILESERVICE.methods_by_name['Get']._serialized_options = b'\202\323\344\223\002<\022:/assistants/v1/searchIndexFile/{search_index_id}/{file_id}'
  _SEARCHINDEXFILESERVICE.methods_by_name['List']._options = None
  _SEARCHINDEXFILESERVICE.methods_by_name['List']._serialized_options = b'\202\323\344\223\0022\0220/assistants/v1/searchIndexFile/{search_index_id}'
  _globals['_GETSEARCHINDEXFILEREQUEST']._serialized_start=248
  _globals['_GETSEARCHINDEXFILEREQUEST']._serialized_end=329
  _globals['_LISTSEARCHINDEXFILESREQUEST']._serialized_start=331
  _globals['_LISTSEARCHINDEXFILESREQUEST']._serialized_end=430
  _globals['_LISTSEARCHINDEXFILESRESPONSE']._serialized_start=433
  _globals['_LISTSEARCHINDEXFILESRESPONSE']._serialized_end=563
  _globals['_SEARCHINDEXFILESERVICE']._serialized_start=566
  _globals['_SEARCHINDEXFILESERVICE']._serialized_end=1008
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/ai/foundation_models/v1/text_common.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n6yandex/cloud/ai/foundation_models/v1/text_common.proto\x12$yandex.cloud.ai.foundation_models.v1\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1egoogle/protobuf/wrappers.proto\"\x87\x01\n\x11\x43ompletionOptions\x12\x0e\n\x06stream\x18\x01 \x01(\x08\x12\x31\n\x0btemperature\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12/\n\nmax_tokens\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\"2\n\x07Message\x12\x0c\n\x04role\x18\x01 \x01(\t\x12\x0e\n\x04text\x18\x02 \x01(\tH\x00\x42\t\n\x07\x43ontent\"Z\n\x0c\x43ontentUsage\x12\x19\n\x11input_text_tokens\x18\x01 \x01(\x03\x12\x19\n\x11\x63ompletion_tokens\x18\x02 \x01(\x03\x12\x14\n\x0ctotal_tokens\x18\x03 \x01(\x03\"\x8c\x03\n\x0b\x41lternative\x12>\n\x07message\x18\x01 \x01(\x0b\x32-.yandex.cloud.ai.foundation_models.v1.Message\x12S\n\x06status\x18\x02 \x01(\x0e\x32\x43.yandex.cloud.ai.foundation_models.v1.Alternative.AlternativeStatus\"\xe7\x01\n\x11\x41lternativeStatus\x12\"\n\x1e\x41LTERNATIVE_STATUS_UNSPECIFIED\x10\x00\x12\x1e\n\x1a\x41LTERNATIVE_STATUS_PARTIAL\x10\x01\x12&\n\"ALTERNATIVE_STATUS_TRUNCATED_FINAL\x10\x02\x12\x1c\n\x18\x41LTERNATIVE_STATUS_FINAL\x10\x03\x12%\n!ALTERNATIVE_STATUS_CONTENT_FILTER\x10\x04\x12!\n\x1d\x41LTERNATIVE_STATUS_TOOL_CALLS\x10\x05\"2\n\x05Token\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x0c\n\x04text\x18\x02 \x01(\t\x12\x0f\n\x07special\x18\x03 \x01(\x08\"V\n\x04Tool\x12\x42\n\x08\x66unction\x18\x01 \x01(\x0b\x32..yandex.cloud.ai.foundation_models.v1.FunctionH\x00\x42\n\n\x08ToolType\"Z\n\x08\x46unction\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12+\n\nparameters\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\"g\n\x08ToolCall\x12K\n\rfunction_call\x18\x01 \x01(\x0b\x32\x32.yandex.cloud.ai.foundation_models.v1.FunctionCallH\x00\x42\x0e\n\x0cToolCallType\"H\n\x0c\x46unctionCall\x12\x0c\n\x04name\x18\x01 \x01(\t\x12*\n\targuments\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct\"R\n\x0cToolCallList\x12\x42\n\ntool_calls\x18\x01 \x03(\x0b\x32..yandex.cloud.ai.foundation_models.v1.ToolCall\"o\n\nToolResult\x12O\n\x0f\x66unction_result\x18\x01 \x01(\x0b\x32\x34.yandex.cloud.ai.foundation_models.v1.FunctionResultH\x00\x42\x10\n\x0eToolResultType\"@\n\x0e\x46unctionResult\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x11\n\x07\x63ontent\x18\x02 \x01(\tH\x00\x42\r\n\x0b\x43ontentType\"X\n\x0eToolResultList\x12\x46\n\x0ctool_results\x18\x01 \x03(\x0b\x32\x30.yandex.cloud.ai.foundation_models.v1.ToolResultB\x86\x01\n(yandex.cloud.api.ai.foundation_models.v1ZZgithub.com/yandex-cloud/go-genproto/yandex/cloud/ai/foundation_models/v1;foundation_modelsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.ai.foundation_models.v1.text_common_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n(yandex.cloud.api.ai.foundation_models.v1ZZgithub.com/yandex-cloud/go-genproto/yandex/cloud/ai/foundation_models/v1;foundation_models'
  _globals['_COMPLETIONOPTIONS']._serialized_start=159
  _globals['_COMPLETIONOPTIONS']._serialized_end=294
  _globals['_MESSAGE']._serialized_start=296
  _globals['_MESSAGE']._serialized_end=346
  _globals['_CONTENTUSAGE']._serialized_start=348
  _globals['_CONTENTUSAGE']._serialized_end=438
  _globals['_ALTERNATIVE']._serialized_start=441
  _globals['_ALTERNATIVE']._serialized_end=837
  _globals['_ALTERNATIVE_ALTERNATIVESTATUS']._serialized_start=606
  _globals['_ALTERNATIVE_ALTERNATIVESTATUS']._serialized_end=837
  _globals['_TOKEN']._serialized_start=839
  _globals['_TOKEN']._serialized_end=889
  _globals['_TOOL']._serialized_start=891
  _globals['_TOOL']._serialized_end=977
  _globals['_FUNCTION']._serialized_start=979
  _globals['_FUNCTION']._serialized_end=1069
  _globals['_TOOLCALL']._serialized_start=1071
  _globals['_TOOLCALL']._serialized_end=1174
  _globals['_FUNCTIONCALL']._serialized_start=1176
  _globals['_FUNCTIONCALL']._serialized_end=1248
  _globals['_TOOLCALLLIST']._serialized_start=1250
  _globals['_TOOLCALLLIST']._serialized_end=1332
  _globals['_TOOLRESULT']._serialized_start=1334
  _globals['_TOOLRESULT']._serialized_end=1445
  _globals['_FUNCTIONRESULT']._serialized_start=1447
  _globals['_FUNCTIONRESULT']._serialized_end=1511
  _globals['_TOOLRESULTLIST']._serialized_start=1513
  _globals['_TOOLRESULTLIST']._serialized_end=1601
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/datasphere/v2/restrictions.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-yandex/cloud/datasphere/v2/restrictions.proto\x12\x1ayandex.cloud.datasphere.v2\"\xd8\x01\n\x0fRestrictionMeta\x12\x0c\n\x04name\x18\x01 \x01(\t\x12T\n\nvalue_type\x18\x02 \x01(\x0e\x32@.yandex.cloud.datasphere.v2.RestrictionMeta.RestrictionValueType\"a\n\x14RestrictionValueType\x12&\n\"RESTRICTION_VALUE_TYPE_UNSPECIFIED\x10\x00\x12\x0b\n\x07\x42OOLEAN\x10\x01\x12\x08\n\x04LONG\x10\x02\x12\n\n\x06STRING\x10\x03\"Y\n\x0bRestriction\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x12\n\nbool_value\x18\x02 \x03(\x08\x12\x12\n\nlong_value\x18\x03 \x03(\x03\x12\x14\n\x0cstring_value\x18\x04 \x03(\t\"e\n\x1bGetRestrictionsMetaResponse\x12\x46\n\x11restrictions_meta\x18\x01 \x03(\x0b\x32+.yandex.cloud.datasphere.v2.RestrictionMeta\"U\n\x14RestrictionsResponse\x12=\n\x0crestrictions\x18\x01 \x03(\x0b\x32\'.yandex.cloud.datasphere.v2.RestrictionBk\n\x1eyandex.cloud.api.datasphere.v2ZIgithub.com/yandex-cloud/go-genproto/yandex/cloud/datasphere/v2;datasphereb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.datasphere.v2.restrictions_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\036yandex.cloud.api.datasphere.v2ZIgithub.com/yandex-cloud/go-genproto/yandex/cloud/datasphere/v2;datasphere'
  _globals['_RESTRICTIONMETA']._serialized_start=78
  _globals['_RESTRICTIONMETA']._serialized_end=294
  _globals['_RESTRICTIONMETA_RESTRICTIONVALUETYPE']._serialized_start=197
  _globals['_RESTRICTIONMETA_RESTRICTIONVALUETYPE']._serialized_end=294
  _globals['_RESTRICTION']._serialized_start=296
  _globals['_RESTRICTION']._serialized_end=385
  _globals['_GETRESTRICTIONSMETARESPONSE']._serialized_start=387
  _globals['_GETRESTRICTIONSMETARESPONSE']._serialized_end=488
  _globals['_RESTRICTIONSRESPONSE']._serialized_start=490
  _globals['_RESTRICTIONSRESPONSE']._serialized_end=575
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.iam.v1.workload.federated_credential_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetFederatedCredentialRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEDERATED_CREDENTIAL_ID_FIELD_NUMBER: builtins.int
    federated_credential_id: builtins.str
    """ID of the federated credential to return.
    To get the federated credential ID, make a [FederatedCredentialService.List] request.
    """
    def __init__(
        self,
        *,
        federated_credential_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["federated_credential_id", b"federated_credential_id"]) -> None: ...

global___GetFederatedCredentialRequest = GetFederatedCredentialRequest

@typing.final
class ListFederatedCredentialsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SERVICE_ACCOUNT_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    service_account_id: builtins.str
    """ID of the service account to list federated credentials for.
    To get the the service account ID make a [yandex.cloud.iam.v1.ServiceAccountService.List] request.
    """
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than [page_size],
    the service returns a [ListFederatedCredentialsResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    Default value: 100.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set [page_token]
    to the [ListFederatedCredentialsResponse.next_page_token]
    returned by a previous list request.
    """
    def __init__(
        self,
        *,
        service_account_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["page_size", b"page_size", "page_token", b"page_token", "service_account_id", b"service_account_id"]) -> None: ...

global___ListFederatedCredentialsRequest = ListFederatedCredentialsRequest

@typing.final
class ListFederatedCredentialsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEDERATED_CREDENTIALS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """This token allows you to get the next page of results for list requests. If the number of results
    is larger than [ListFederatedCredentialsRequest.page_size], use
    the [next_page_token] as the value
    for the [ListFederatedCredentialsRequest.page_token] query parameter
    in the next list request. Each subsequent list request will have its own
    [next_page_token] to continue paging through the results.
    """
    @property
    def federated_credentials(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.iam.v1.workload.federated_credential_pb2.FederatedCredential]:
        """List of federated credentials."""

    def __init__(
        self,
        *,
        federated_credentials: collections.abc.Iterable[yandex.cloud.iam.v1.workload.federated_credential_pb2.FederatedCredential] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["federated_credentials", b"federated_credentials", "next_page_token", b"next_page_token"]) -> None: ...

global___ListFederatedCredentialsResponse = ListFederatedCredentialsResponse

@typing.final
class CreateFederatedCredentialRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SERVICE_ACCOUNT_ID_FIELD_NUMBER: builtins.int
    FEDERATION_ID_FIELD_NUMBER: builtins.int
    EXTERNAL_SUBJECT_ID_FIELD_NUMBER: builtins.int
    service_account_id: builtins.str
    """ID of the service account to create a federated credential for.
    To get the service account ID, use a [yandex.cloud.iam.v1.ServiceAccountService.List] request.
    """
    federation_id: builtins.str
    """ID of the workload identity federation that is used for authentication."""
    external_subject_id: builtins.str
    """Id of the external subject."""
    def __init__(
        self,
        *,
        service_account_id: builtins.str = ...,
        federation_id: builtins.str = ...,
        external_subject_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["external_subject_id", b"external_subject_id", "federation_id", b"federation_id", "service_account_id", b"service_account_id"]) -> None: ...

global___CreateFederatedCredentialRequest = CreateFederatedCredentialRequest

@typing.final
class CreateFederatedCredentialMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEDERATED_CREDENTIAL_ID_FIELD_NUMBER: builtins.int
    federated_credential_id: builtins.str
    """ID of the federated credential that is being created."""
    def __init__(
        self,
        *,
        federated_credential_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["federated_credential_id", b"federated_credential_id"]) -> None: ...

global___CreateFederatedCredentialMetadata = CreateFederatedCredentialMetadata

@typing.final
class DeleteFederatedCredentialRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEDERATED_CREDENTIAL_ID_FIELD_NUMBER: builtins.int
    federated_credential_id: builtins.str
    """ID of the federated credential key to delete.
    To get the federated credential ID, use a [FederatedCredentialService.List] request.
    """
    def __init__(
        self,
        *,
        federated_credential_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["federated_credential_id", b"federated_credential_id"]) -> None: ...

global___DeleteFederatedCredentialRequest = DeleteFederatedCredentialRequest

@typing.final
class DeleteFederatedCredentialMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEDERATED_CREDENTIAL_ID_FIELD_NUMBER: builtins.int
    federated_credential_id: builtins.str
    """ID of the federated credential that is being deleted."""
    def __init__(
        self,
        *,
        federated_credential_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["federated_credential_id", b"federated_credential_id"]) -> None: ...

global___DeleteFederatedCredentialMetadata = DeleteFederatedCredentialMetadata



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _PrivateKeyFormat:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _PrivateKeyFormatEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_PrivateKeyFormat.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    PRIVATE_KEY_FORMAT_UNSPECIFIED: _PrivateKeyFormat.ValueType  # 0
    PKCS1: _PrivateKeyFormat.ValueType  # 1
    PKCS8: _PrivateKeyFormat.ValueType  # 2

class PrivateKeyFormat(_PrivateKeyFormat, metaclass=_PrivateKeyFormatEnumTypeWrapper): ...

PRIVATE_KEY_FORMAT_UNSPECIFIED: PrivateKeyFormat.ValueType  # 0
PKCS1: PrivateKeyFormat.ValueType  # 1
PKCS8: PrivateKeyFormat.ValueType  # 2
global___PrivateKeyFormat = PrivateKeyFormat

@typing.final
class GetCertificateContentResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CERTIFICATE_ID_FIELD_NUMBER: builtins.int
    CERTIFICATE_CHAIN_FIELD_NUMBER: builtins.int
    PRIVATE_KEY_FIELD_NUMBER: builtins.int
    certificate_id: builtins.str
    """ID of the certificate."""
    private_key: builtins.str
    """PEM-encoded private key content of the certificate."""
    @property
    def certificate_chain(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """PEM-encoded certificate chain content of the certificate."""

    def __init__(
        self,
        *,
        certificate_id: builtins.str = ...,
        certificate_chain: collections.abc.Iterable[builtins.str] | None = ...,
        private_key: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["certificate_chain", b"certificate_chain", "certificate_id", b"certificate_id", "private_key", b"private_key"]) -> None: ...

global___GetCertificateContentResponse = GetCertificateContentResponse

@typing.final
class GetCertificateContentRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CERTIFICATE_ID_FIELD_NUMBER: builtins.int
    VERSION_ID_FIELD_NUMBER: builtins.int
    PRIVATE_KEY_FORMAT_FIELD_NUMBER: builtins.int
    certificate_id: builtins.str
    """ID of the certificate to download content."""
    version_id: builtins.str
    """Optional ID of the version."""
    private_key_format: global___PrivateKeyFormat.ValueType
    """Desired format of private key"""
    def __init__(
        self,
        *,
        certificate_id: builtins.str = ...,
        version_id: builtins.str = ...,
        private_key_format: global___PrivateKeyFormat.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["certificate_id", b"certificate_id", "private_key_format", b"private_key_format", "version_id", b"version_id"]) -> None: ...

global___GetCertificateContentRequest = GetCertificateContentRequest



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.access.access_pb2
import yandex.cloud.kms.v1.symmetric_key_pb2
import yandex.cloud.kms.v1.symmetric_key_service_pb2
import yandex.cloud.operation.operation_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class SymmetricKeyServiceStub:
    """Set of methods for managing symmetric KMS keys."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Create: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.kms.v1.symmetric_key_service_pb2.CreateSymmetricKeyRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """--- control plane

    Creates a symmetric KMS key in the specified folder.
    """

    Get: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.kms.v1.symmetric_key_service_pb2.GetSymmetricKeyRequest,
        yandex.cloud.kms.v1.symmetric_key_pb2.SymmetricKey,
    ]
    """Returns the specified symmetric KMS key.

     To get the list of available symmetric KMS keys, make a [SymmetricKeyService.List] request.
    """

    List: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.kms.v1.symmetric_key_service_pb2.ListSymmetricKeysRequest,
        yandex.cloud.kms.v1.symmetric_key_service_pb2.ListSymmetricKeysResponse,
    ]
    """Returns the list of symmetric KMS keys in the specified folder."""

    ListVersions: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.kms.v1.symmetric_key_service_pb2.ListSymmetricKeyVersionsRequest,
        yandex.cloud.kms.v1.symmetric_key_service_pb2.ListSymmetricKeyVersionsResponse,
    ]
    """Returns the list of versions of the specified symmetric KMS key."""

    Update: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.kms.v1.symmetric_key_service_pb2.UpdateSymmetricKeyRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the specified symmetric KMS key."""

    Delete: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.kms.v1.symmetric_key_service_pb2.DeleteSymmetricKeyRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified symmetric KMS key. This action also automatically schedules
    the destruction of all of the key's versions in 72 hours.

    The key and its versions appear absent in [SymmetricKeyService.Get] and [SymmetricKeyService.List]
    requests, but can be restored within 72 hours with a request to tech support.
    """

    SetPrimaryVersion: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.kms.v1.symmetric_key_service_pb2.SetPrimarySymmetricKeyVersionRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Sets the primary version for the specified key. The primary version is used
    by default for all encrypt/decrypt operations where no version ID is specified.
    """

    ScheduleVersionDestruction: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.kms.v1.symmetric_key_service_pb2.ScheduleSymmetricKeyVersionDestructionRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Schedules the specified key version for destruction.

    Scheduled destruction can be cancelled with the [SymmetricKeyService.CancelVersionDestruction] method.
    """

    CancelVersionDestruction: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.kms.v1.symmetric_key_service_pb2.CancelSymmetricKeyVersionDestructionRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Cancels previously scheduled version destruction, if the version hasn't been destroyed yet."""

    Rotate: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.kms.v1.symmetric_key_service_pb2.RotateSymmetricKeyRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Rotates the specified key: creates a new key version and makes it the primary version.
    The old version remains available for decryption of ciphertext encrypted with it.
    """

    ListOperations: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.kms.v1.symmetric_key_service_pb2.ListSymmetricKeyOperationsRequest,
        yandex.cloud.kms.v1.symmetric_key_service_pb2.ListSymmetricKeyOperationsResponse,
    ]
    """Lists operations for the specified symmetric KMS key."""

    ListAccessBindings: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.ListAccessBindingsRequest,
        yandex.cloud.access.access_pb2.ListAccessBindingsResponse,
    ]
    """Lists existing access bindings for the specified key."""

    SetAccessBindings: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.SetAccessBindingsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Sets access bindings for the key."""

    UpdateAccessBindings: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.UpdateAccessBindingsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates access bindings for the specified key."""

class SymmetricKeyServiceAsyncStub:
    """Set of methods for managing symmetric KMS keys."""

    Create: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.kms.v1.symmetric_key_service_pb2.CreateSymmetricKeyRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """--- control plane

    Creates a symmetric KMS key in the specified folder.
    """

    Get: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.kms.v1.symmetric_key_service_pb2.GetSymmetricKeyRequest,
        yandex.cloud.kms.v1.symmetric_key_pb2.SymmetricKey,
    ]
    """Returns the specified symmetric KMS key.

     To get the list of available symmetric KMS keys, make a [SymmetricKeyService.List] request.
    """

    List: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.kms.v1.symmetric_key_service_pb2.ListSymmetricKeysRequest,
        yandex.cloud.kms.v1.symmetric_key_service_pb2.ListSymmetricKeysResponse,
    ]
    """Returns the list of symmetric KMS keys in the specified folder."""

    ListVersions: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.kms.v1.symmetric_key_service_pb2.ListSymmetricKeyVersionsRequest,
        yandex.cloud.kms.v1.symmetric_key_service_pb2.ListSymmetricKeyVersionsResponse,
    ]
    """Returns the list of versions of the specified symmetric KMS key."""

    Update: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.kms.v1.symmetric_key_service_pb2.UpdateSymmetricKeyRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the specified symmetric KMS key."""

    Delete: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.kms.v1.symmetric_key_service_pb2.DeleteSymmetricKeyRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified symmetric KMS key. This action also automatically schedules
    the destruction of all of the key's versions in 72 hours.

    The key and its versions appear absent in [SymmetricKeyService.Get] and [SymmetricKeyService.List]
    requests, but can be restored within 72 hours with a request to tech support.
    """

    SetPrimaryVersion: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.kms.v1.symmetric_key_service_pb2.SetPrimarySymmetricKeyVersionRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Sets the primary version for the specified key. The primary version is used
    by default for all encrypt/decrypt operations where no version ID is specified.
    """

    ScheduleVersionDestruction: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.kms.v1.symmetric_key_service_pb2.ScheduleSymmetricKeyVersionDestructionRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Schedules the specified key version for destruction.

    Scheduled destruction can be cancelled with the [SymmetricKeyService.CancelVersionDestruction] method.
    """

    CancelVersionDestruction: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.kms.v1.symmetric_key_service_pb2.CancelSymmetricKeyVersionDestructionRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Cancels previously scheduled version destruction, if the version hasn't been destroyed yet."""

    Rotate: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.kms.v1.symmetric_key_service_pb2.RotateSymmetricKeyRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Rotates the specified key: creates a new key version and makes it the primary version.
    The old version remains available for decryption of ciphertext encrypted with it.
    """

    ListOperations: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.kms.v1.symmetric_key_service_pb2.ListSymmetricKeyOperationsRequest,
        yandex.cloud.kms.v1.symmetric_key_service_pb2.ListSymmetricKeyOperationsResponse,
    ]
    """Lists operations for the specified symmetric KMS key."""

    ListAccessBindings: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.ListAccessBindingsRequest,
        yandex.cloud.access.access_pb2.ListAccessBindingsResponse,
    ]
    """Lists existing access bindings for the specified key."""

    SetAccessBindings: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.SetAccessBindingsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Sets access bindings for the key."""

    UpdateAccessBindings: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.UpdateAccessBindingsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates access bindings for the specified key."""

class SymmetricKeyServiceServicer(metaclass=abc.ABCMeta):
    """Set of methods for managing symmetric KMS keys."""

    @abc.abstractmethod
    def Create(
        self,
        request: yandex.cloud.kms.v1.symmetric_key_service_pb2.CreateSymmetricKeyRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """--- control plane

        Creates a symmetric KMS key in the specified folder.
        """

    @abc.abstractmethod
    def Get(
        self,
        request: yandex.cloud.kms.v1.symmetric_key_service_pb2.GetSymmetricKeyRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.kms.v1.symmetric_key_pb2.SymmetricKey, collections.abc.Awaitable[yandex.cloud.kms.v1.symmetric_key_pb2.SymmetricKey]]:
        """Returns the specified symmetric KMS key.

         To get the list of available symmetric KMS keys, make a [SymmetricKeyService.List] request.
        """

    @abc.abstractmethod
    def List(
        self,
        request: yandex.cloud.kms.v1.symmetric_key_service_pb2.ListSymmetricKeysRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.kms.v1.symmetric_key_service_pb2.ListSymmetricKeysResponse, collections.abc.Awaitable[yandex.cloud.kms.v1.symmetric_key_service_pb2.ListSymmetricKeysResponse]]:
        """Returns the list of symmetric KMS keys in the specified folder."""

    @abc.abstractmethod
    def ListVersions(
        self,
        request: yandex.cloud.kms.v1.symmetric_key_service_pb2.ListSymmetricKeyVersionsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.kms.v1.symmetric_key_service_pb2.ListSymmetricKeyVersionsResponse, collections.abc.Awaitable[yandex.cloud.kms.v1.symmetric_key_service_pb2.ListSymmetricKeyVersionsResponse]]:
        """Returns the list of versions of the specified symmetric KMS key."""

    @abc.abstractmethod
    def Update(
        self,
        request: yandex.cloud.kms.v1.symmetric_key_service_pb2.UpdateSymmetricKeyRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Updates the specified symmetric KMS key."""

    @abc.abstractmethod
    def Delete(
        self,
        request: yandex.cloud.kms.v1.symmetric_key_service_pb2.DeleteSymmetricKeyRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Deletes the specified symmetric KMS key. This action also automatically schedules
        the destruction of all of the key's versions in 72 hours.

        The key and its versions appear absent in [SymmetricKeyService.Get] and [SymmetricKeyService.List]
        requests, but can be restored within 72 hours with a request to tech support.
        """

    @abc.abstractmethod
    def SetPrimaryVersion(
        self,
        request: yandex.cloud.kms.v1.symmetric_key_service_pb2.SetPrimarySymmetricKeyVersionRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Sets the primary version for the specified key. The primary version is used
        by default for all encrypt/decrypt operations where no version ID is specified.
        """

    @abc.abstractmethod
    def ScheduleVersionDestruction(
        self,
        request: yandex.cloud.kms.v1.symmetric_key_service_pb2.ScheduleSymmetricKeyVersionDestructionRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Schedules the specified key version for destruction.

        Scheduled destruction can be cancelled with the [SymmetricKeyService.CancelVersionDestruction] method.
        """

    @abc.abstractmethod
    def CancelVersionDestruction(
        self,
        request: yandex.cloud.kms.v1.symmetric_key_service_pb2.CancelSymmetricKeyVersionDestructionRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Cancels previously scheduled version destruction, if the version hasn't been destroyed yet."""

    @abc.abstractmethod
    def Rotate(
        self,
        request: yandex.cloud.kms.v1.symmetric_key_service_pb2.RotateSymmetricKeyRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Rotates the specified key: creates a new key version and makes it the primary version.
        The old version remains available for decryption of ciphertext encrypted with it.
        """

    @abc.abstractmethod
    def ListOperations(
        self,
        request: yandex.cloud.kms.v1.symmetric_key_service_pb2.ListSymmetricKeyOperationsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.kms.v1.symmetric_key_service_pb2.ListSymmetricKeyOperationsResponse, collections.abc.Awaitable[yandex.cloud.kms.v1.symmetric_key_service_pb2.ListSymmetricKeyOperationsResponse]]:
        """Lists operations for the specified symmetric KMS key."""

    @abc.abstractmethod
    def ListAccessBindings(
        self,
        request: yandex.cloud.access.access_pb2.ListAccessBindingsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.access.access_pb2.ListAccessBindingsResponse, collections.abc.Awaitable[yandex.cloud.access.access_pb2.ListAccessBindingsResponse]]:
        """Lists existing access bindings for the specified key."""

    @abc.abstractmethod
    def SetAccessBindings(
        self,
        request: yandex.cloud.access.access_pb2.SetAccessBindingsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Sets access bindings for the key."""

    @abc.abstractmethod
    def UpdateAccessBindings(
        self,
        request: yandex.cloud.access.access_pb2.UpdateAccessBindingsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Updates access bindings for the specified key."""

def add_SymmetricKeyServiceServicer_to_server(servicer: SymmetricKeyServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.cic.v1.trunk_connection_pb2
import yandex.cloud.cic.v1.trunk_connection_service_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class TrunkConnectionServiceStub:
    """A set of methods for managing TrunkConnection resources."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Get: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.cic.v1.trunk_connection_service_pb2.GetTrunkConnectionRequest,
        yandex.cloud.cic.v1.trunk_connection_pb2.TrunkConnection,
    ]
    """Returns the specified TrunkConnection resource.

    To get the list of available TrunkConnection resources, make a [List] request.
    """

    List: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.cic.v1.trunk_connection_service_pb2.ListTrunkConnectionsRequest,
        yandex.cloud.cic.v1.trunk_connection_service_pb2.ListTrunkConnectionsResponse,
    ]
    """Retrieves the list of TrunkConnection resources in the specified folder."""

class TrunkConnectionServiceAsyncStub:
    """A set of methods for managing TrunkConnection resources."""

    Get: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.cic.v1.trunk_connection_service_pb2.GetTrunkConnectionRequest,
        yandex.cloud.cic.v1.trunk_connection_pb2.TrunkConnection,
    ]
    """Returns the specified TrunkConnection resource.

    To get the list of available TrunkConnection resources, make a [List] request.
    """

    List: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.cic.v1.trunk_connection_service_pb2.ListTrunkConnectionsRequest,
        yandex.cloud.cic.v1.trunk_connection_service_pb2.ListTrunkConnectionsResponse,
    ]
    """Retrieves the list of TrunkConnection resources in the specified folder."""

class TrunkConnectionServiceServicer(metaclass=abc.ABCMeta):
    """A set of methods for managing TrunkConnection resources."""

    @abc.abstractmethod
    def Get(
        self,
        request: yandex.cloud.cic.v1.trunk_connection_service_pb2.GetTrunkConnectionRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.cic.v1.trunk_connection_pb2.TrunkConnection, collections.abc.Awaitable[yandex.cloud.cic.v1.trunk_connection_pb2.TrunkConnection]]:
        """Returns the specified TrunkConnection resource.

        To get the list of available TrunkConnection resources, make a [List] request.
        """

    @abc.abstractmethod
    def List(
        self,
        request: yandex.cloud.cic.v1.trunk_connection_service_pb2.ListTrunkConnectionsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.cic.v1.trunk_connection_service_pb2.ListTrunkConnectionsResponse, collections.abc.Awaitable[yandex.cloud.cic.v1.trunk_connection_service_pb2.ListTrunkConnectionsResponse]]:
        """Retrieves the list of TrunkConnection resources in the specified folder."""

def add_TrunkConnectionServiceServicer_to_server(servicer: TrunkConnectionServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/compute/v1/filesystem_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.access import access_pb2 as yandex_dot_cloud_dot_access_dot_access__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.compute.v1 import filesystem_pb2 as yandex_dot_cloud_dot_compute_dot_v1_dot_filesystem__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n0yandex/cloud/compute/v1/filesystem_service.proto\x12\x17yandex.cloud.compute.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a yandex/cloud/access/access.proto\x1a yandex/cloud/api/operation.proto\x1a(yandex/cloud/compute/v1/filesystem.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\";\n\x14GetFilesystemRequest\x12#\n\rfilesystem_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\xb0\x01\n\x16ListFilesystemsRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\x12\x1b\n\x08order_by\x18\x05 \x01(\tB\t\x8a\xc8\x31\x05<=100\"l\n\x17ListFilesystemsResponse\x12\x38\n\x0b\x66ilesystems\x18\x01 \x03(\x0b\x32#.yandex.cloud.compute.v1.Filesystem\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xb3\x03\n\x17\x43reateFilesystemRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x32\n\x04name\x18\x02 \x01(\tB$\xf2\xc7\x31 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x91\x01\n\x06labels\x18\x04 \x03(\x0b\x32<.yandex.cloud.compute.v1.CreateFilesystemRequest.LabelsEntryBC\xf2\xc7\x31\x0f[-_./\\@0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x1c\x12\x14[a-z][-_./\\@0-9a-z]*\x1a\x04\x31-63\x12\x19\n\x07type_id\x18\x05 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12\x1d\n\x07zone_id\x18\x06 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x12\n\x04size\x18\x07 \x01(\x03\x42\x04\xe8\xc7\x31\x01\x12\x12\n\nblock_size\x18\x08 \x01(\x03\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"1\n\x18\x43reateFilesystemMetadata\x12\x15\n\rfilesystem_id\x18\x01 \x01(\t\"\x94\x03\n\x17UpdateFilesystemRequest\x12#\n\rfilesystem_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x32\n\x04name\x18\x03 \x01(\tB$\xf2\xc7\x31 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?\x12\x1e\n\x0b\x64\x65scription\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x91\x01\n\x06labels\x18\x05 \x03(\x0b\x32<.yandex.cloud.compute.v1.UpdateFilesystemRequest.LabelsEntryBC\xf2\xc7\x31\x0f[-_./\\@0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x1c\x12\x14[a-z][-_./\\@0-9a-z]*\x1a\x04\x31-63\x12\x0c\n\x04size\x18\x06 \x01(\x03\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"1\n\x18UpdateFilesystemMetadata\x12\x15\n\rfilesystem_id\x18\x01 \x01(\t\">\n\x17\x44\x65leteFilesystemRequest\x12#\n\rfilesystem_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"1\n\x18\x44\x65leteFilesystemMetadata\x12\x15\n\rfilesystem_id\x18\x01 \x01(\t\"\x84\x01\n\x1fListFilesystemOperationsRequest\x12#\n\rfilesystem_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"r\n ListFilesystemOperationsResponse\x12\x35\n\noperations\x18\x01 \x03(\x0b\x32!.yandex.cloud.operation.Operation\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t2\xdb\r\n\x11\x46ilesystemService\x12\x8a\x01\n\x03Get\x12-.yandex.cloud.compute.v1.GetFilesystemRequest\x1a#.yandex.cloud.compute.v1.Filesystem\"/\x82\xd3\xe4\x93\x02)\x12\'/compute/v1/filesystems/{filesystem_id}\x12\x8a\x01\n\x04List\x12/.yandex.cloud.compute.v1.ListFilesystemsRequest\x1a\x30.yandex.cloud.compute.v1.ListFilesystemsResponse\"\x1f\x82\xd3\xe4\x93\x02\x19\x12\x17/compute/v1/filesystems\x12\xab\x01\n\x06\x43reate\x12\x30.yandex.cloud.compute.v1.CreateFilesystemRequest\x1a!.yandex.cloud.operation.Operation\"L\xb2\xd2*&\n\x18\x43reateFilesystemMetadata\x12\nFilesystem\x82\xd3\xe4\x93\x02\x1c\"\x17/compute/v1/filesystems:\x01*\x12\xbb\x01\n\x06Update\x12\x30.yandex.cloud.compute.v1.UpdateFilesystemRequest\x1a!.yandex.cloud.operation.Operation\"\\\xb2\xd2*&\n\x18UpdateFilesystemMetadata\x12\nFilesystem\x82\xd3\xe4\x93\x02,2\'/compute/v1/filesystems/{filesystem_id}:\x01*\x12\xc3\x01\n\x06\x44\x65lete\x12\x30.yandex.cloud.compute.v1.DeleteFilesystemRequest\x1a!.yandex.cloud.operation.Operation\"d\xb2\xd2*1\n\x18\x44\x65leteFilesystemMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02)*\'/compute/v1/filesystems/{filesystem_id}\x12\xc1\x01\n\x0eListOperations\x12\x38.yandex.cloud.compute.v1.ListFilesystemOperationsRequest\x1a\x39.yandex.cloud.compute.v1.ListFilesystemOperationsResponse\":\x82\xd3\xe4\x93\x02\x34\x12\x32/compute/v1/filesystems/{filesystem_id}/operations\x12\xb7\x01\n\x12ListAccessBindings\x12..yandex.cloud.access.ListAccessBindingsRequest\x1a/.yandex.cloud.access.ListAccessBindingsResponse\"@\x82\xd3\xe4\x93\x02:\x12\x38/compute/v1/filesystems/{resource_id}:listAccessBindings\x12\xf6\x01\n\x11SetAccessBindings\x12-.yandex.cloud.access.SetAccessBindingsRequest\x1a!.yandex.cloud.operation.Operation\"\x8e\x01\xb2\xd2*H\n access.SetAccessBindingsMetadata\x12$access.AccessBindingsOperationResult\x82\xd3\xe4\x93\x02<\"7/compute/v1/filesystems/{resource_id}:setAccessBindings:\x01*\x12\x82\x02\n\x14UpdateAccessBindings\x12\x30.yandex.cloud.access.UpdateAccessBindingsRequest\x1a!.yandex.cloud.operation.Operation\"\x94\x01\xb2\xd2*K\n#access.UpdateAccessBindingsMetadata\x12$access.AccessBindingsOperationResult\x82\xd3\xe4\x93\x02?\":/compute/v1/filesystems/{resource_id}:updateAccessBindings:\x01*Bb\n\x1byandex.cloud.api.compute.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/compute/v1;computeb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.compute.v1.filesystem_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\033yandex.cloud.api.compute.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/compute/v1;compute'
  _GETFILESYSTEMREQUEST.fields_by_name['filesystem_id']._options = None
  _GETFILESYSTEMREQUEST.fields_by_name['filesystem_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTFILESYSTEMSREQUEST.fields_by_name['folder_id']._options = None
  _LISTFILESYSTEMSREQUEST.fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTFILESYSTEMSREQUEST.fields_by_name['page_size']._options = None
  _LISTFILESYSTEMSREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _LISTFILESYSTEMSREQUEST.fields_by_name['page_token']._options = None
  _LISTFILESYSTEMSREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _LISTFILESYSTEMSREQUEST.fields_by_name['filter']._options = None
  _LISTFILESYSTEMSREQUEST.fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _LISTFILESYSTEMSREQUEST.fields_by_name['order_by']._options = None
  _LISTFILESYSTEMSREQUEST.fields_by_name['order_by']._serialized_options = b'\212\3101\005<=100'
  _CREATEFILESYSTEMREQUEST_LABELSENTRY._options = None
  _CREATEFILESYSTEMREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _CREATEFILESYSTEMREQUEST.fields_by_name['folder_id']._options = None
  _CREATEFILESYSTEMREQUEST.fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _CREATEFILESYSTEMREQUEST.fields_by_name['name']._options = None
  _CREATEFILESYSTEMREQUEST.fields_by_name['name']._serialized_options = b'\362\3071 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?'
  _CREATEFILESYSTEMREQUEST.fields_by_name['description']._options = None
  _CREATEFILESYSTEMREQUEST.fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _CREATEFILESYSTEMREQUEST.fields_by_name['labels']._options = None
  _CREATEFILESYSTEMREQUEST.fields_by_name['labels']._serialized_options = b'\362\3071\017[-_./\\@0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\034\022\024[a-z][-_./\\@0-9a-z]*\032\0041-63'
  _CREATEFILESYSTEMREQUEST.fields_by_name['type_id']._options = None
  _CREATEFILESYSTEMREQUEST.fields_by_name['type_id']._serialized_options = b'\212\3101\004<=50'
  _CREATEFILESYSTEMREQUEST.fields_by_name['zone_id']._options = None
  _CREATEFILESYSTEMREQUEST.fields_by_name['zone_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _CREATEFILESYSTEMREQUEST.fields_by_name['size']._options = None
  _CREATEFILESYSTEMREQUEST.fields_by_name['size']._serialized_options = b'\350\3071\001'
  _UPDATEFILESYSTEMREQUEST_LABELSENTRY._options = None
  _UPDATEFILESYSTEMREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _UPDATEFILESYSTEMREQUEST.fields_by_name['filesystem_id']._options = None
  _UPDATEFILESYSTEMREQUEST.fields_by_name['filesystem_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _UPDATEFILESYSTEMREQUEST.fields_by_name['name']._options = None
  _UPDATEFILESYSTEMREQUEST.fields_by_name['name']._serialized_options = b'\362\3071 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?'
  _UPDATEFILESYSTEMREQUEST.fields_by_name['description']._options = None
  _UPDATEFILESYSTEMREQUEST.fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _UPDATEFILESYSTEMREQUEST.fields_by_name['labels']._options = None
  _UPDATEFILESYSTEMREQUEST.fields_by_name['labels']._serialized_options = b'\362\3071\017[-_./\\@0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\034\022\024[a-z][-_./\\@0-9a-z]*\032\0041-63'
  _DELETEFILESYSTEMREQUEST.fields_by_name['filesystem_id']._options = None
  _DELETEFILESYSTEMREQUEST.fields_by_name['filesystem_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTFILESYSTEMOPERATIONSREQUEST.fields_by_name['filesystem_id']._options = None
  _LISTFILESYSTEMOPERATIONSREQUEST.fields_by_name['filesystem_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTFILESYSTEMOPERATIONSREQUEST.fields_by_name['page_size']._options = None
  _LISTFILESYSTEMOPERATIONSREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _LISTFILESYSTEMOPERATIONSREQUEST.fields_by_name['page_token']._options = None
  _LISTFILESYSTEMOPERATIONSREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _FILESYSTEMSERVICE.methods_by_name['Get']._options = None
  _FILESYSTEMSERVICE.methods_by_name['Get']._serialized_options = b'\202\323\344\223\002)\022\'/compute/v1/filesystems/{filesystem_id}'
  _FILESYSTEMSERVICE.methods_by_name['List']._options = None
  _FILESYSTEMSERVICE.methods_by_name['List']._serialized_options = b'\202\323\344\223\002\031\022\027/compute/v1/filesystems'
  _FILESYSTEMSERVICE.methods_by_name['Create']._options = None
  _FILESYSTEMSERVICE.methods_by_name['Create']._serialized_options = b'\262\322*&\n\030CreateFilesystemMetadata\022\nFilesystem\202\323\344\223\002\034\"\027/compute/v1/filesystems:\001*'
  _FILESYSTEMSERVICE.methods_by_name['Update']._options = None
  _FILESYSTEMSERVICE.methods_by_name['Update']._serialized_options = b'\262\322*&\n\030UpdateFilesystemMetadata\022\nFilesystem\202\323\344\223\002,2\'/compute/v1/filesystems/{filesystem_id}:\001*'
  _FILESYSTEMSERVICE.methods_by_name['Delete']._options = None
  _FILESYSTEMSERVICE.methods_by_name['Delete']._serialized_options = b'\262\322*1\n\030DeleteFilesystemMetadata\022\025google.protobuf.Empty\202\323\344\223\002)*\'/compute/v1/filesystems/{filesystem_id}'
  _FILESYSTEMSERVICE.methods_by_name['ListOperations']._options = None
  _FILESYSTEMSERVICE.methods_by_name['ListOperations']._serialized_options = b'\202\323\344\223\0024\0222/compute/v1/filesystems/{filesystem_id}/operations'
  _FILESYSTEMSERVICE.methods_by_name['ListAccessBindings']._options = None
  _FILESYSTEMSERVICE.methods_by_name['ListAccessBindings']._serialized_options = b'\202\323\344\223\002:\0228/compute/v1/filesystems/{resource_id}:listAccessBindings'
  _FILESYSTEMSERVICE.methods_by_name['SetAccessBindings']._options = None
  _FILESYSTEMSERVICE.methods_by_name['SetAccessBindings']._serialized_options = b'\262\322*H\n access.SetAccessBindingsMetadata\022$access.AccessBindingsOperationResult\202\323\344\223\002<\"7/compute/v1/filesystems/{resource_id}:setAccessBindings:\001*'
  _FILESYSTEMSERVICE.methods_by_name['UpdateAccessBindings']._options = None
  _FILESYSTEMSERVICE.methods_by_name['UpdateAccessBindings']._serialized_options = b'\262\322*K\n#access.UpdateAccessBindingsMetadata\022$access.AccessBindingsOperationResult\202\323\344\223\002?\":/compute/v1/filesystems/{resource_id}:updateAccessBindings:\001*'
  _globals['_GETFILESYSTEMREQUEST']._serialized_start=322
  _globals['_GETFILESYSTEMREQUEST']._serialized_end=381
  _globals['_LISTFILESYSTEMSREQUEST']._serialized_start=384
  _globals['_LISTFILESYSTEMSREQUEST']._serialized_end=560
  _globals['_LISTFILESYSTEMSRESPONSE']._serialized_start=562
  _globals['_LISTFILESYSTEMSRESPONSE']._serialized_end=670
  _globals['_CREATEFILESYSTEMREQUEST']._serialized_start=673
  _globals['_CREATEFILESYSTEMREQUEST']._serialized_end=1108
  _globals['_CREATEFILESYSTEMREQUEST_LABELSENTRY']._serialized_start=1063
  _globals['_CREATEFILESYSTEMREQUEST_LABELSENTRY']._serialized_end=1108
  _globals['_CREATEFILESYSTEMMETADATA']._serialized_start=1110
  _globals['_CREATEFILESYSTEMMETADATA']._serialized_end=1159
  _globals['_UPDATEFILESYSTEMREQUEST']._serialized_start=1162
  _globals['_UPDATEFILESYSTEMREQUEST']._serialized_end=1566
  _globals['_UPDATEFILESYSTEMREQUEST_LABELSENTRY']._serialized_start=1063
  _globals['_UPDATEFILESYSTEMREQUEST_LABELSENTRY']._serialized_end=1108
  _globals['_UPDATEFILESYSTEMMETADATA']._serialized_start=1568
  _globals['_UPDATEFILESYSTEMMETADATA']._serialized_end=1617
  _globals['_DELETEFILESYSTEMREQUEST']._serialized_start=1619
  _globals['_DELETEFILESYSTEMREQUEST']._serialized_end=1681
  _globals['_DELETEFILESYSTEMMETADATA']._serialized_start=1683
  _globals['_DELETEFILESYSTEMMETADATA']._serialized_end=1732
  _globals['_LISTFILESYSTEMOPERATIONSREQUEST']._serialized_start=1735
  _globals['_LISTFILESYSTEMOPERATIONSREQUEST']._serialized_end=1867
  _globals['_LISTFILESYSTEMOPERATIONSRESPONSE']._serialized_start=1869
  _globals['_LISTFILESYSTEMOPERATIONSRESPONSE']._serialized_end=1983
  _globals['_FILESYSTEMSERVICE']._serialized_start=1986
  _globals['_FILESYSTEMSERVICE']._serialized_end=3741
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/ai/files/v1/file_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud.ai.common import common_pb2 as yandex_dot_cloud_dot_ai_dot_common_dot_common__pb2
from yandex.cloud.ai.files.v1 import file_pb2 as yandex_dot_cloud_dot_ai_dot_files_dot_v1_dot_file__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+yandex/cloud/ai/files/v1/file_service.proto\x12\x18yandex.cloud.ai.files.v1\x1a#yandex/cloud/ai/common/common.proto\x1a#yandex/cloud/ai/files/v1/file.proto\x1a\x1dyandex/cloud/validation.proto\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\"\xb6\x02\n\x11\x43reateFileRequest\x12\x17\n\tfolder_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x11\n\tmime_type\x18\x04 \x01(\t\x12\x15\n\x07\x63ontent\x18\x05 \x01(\x0c\x42\x04\xe8\xc7\x31\x01\x12G\n\x06labels\x18\x06 \x03(\x0b\x32\x37.yandex.cloud.ai.files.v1.CreateFileRequest.LabelsEntry\x12\x43\n\x11\x65xpiration_config\x18\x07 \x01(\x0b\x32(.yandex.cloud.ai.common.ExpirationConfig\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\'\n\x0eGetFileRequest\x12\x15\n\x07\x66ile_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"*\n\x11GetFileUrlRequest\x12\x15\n\x07\x66ile_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"!\n\x12GetFileUrlResponse\x12\x0b\n\x03url\x18\x01 \x01(\t\"\xc1\x02\n\x11UpdateFileRequest\x12\x15\n\x07\x66ile_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x35\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x04\xe8\xc7\x31\x01\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\x43\n\x11\x65xpiration_config\x18\x05 \x01(\x0b\x32(.yandex.cloud.ai.common.ExpirationConfig\x12G\n\x06labels\x18\x06 \x03(\x0b\x32\x37.yandex.cloud.ai.files.v1.UpdateFileRequest.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"*\n\x11\x44\x65leteFileRequest\x12\x15\n\x07\x66ile_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"\x14\n\x12\x44\x65leteFileResponse\"R\n\x10ListFilesRequest\x12\x17\n\tfolder_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x11\n\tpage_size\x18\x02 \x01(\x03\x12\x12\n\npage_token\x18\x03 \x01(\t\"[\n\x11ListFilesResponse\x12-\n\x05\x66iles\x18\x01 \x03(\x0b\x32\x1e.yandex.cloud.ai.files.v1.File\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t2\xfb\x05\n\x0b\x46ileService\x12q\n\x06\x43reate\x12+.yandex.cloud.ai.files.v1.CreateFileRequest\x1a\x1e.yandex.cloud.ai.files.v1.File\"\x1a\x82\xd3\xe4\x93\x02\x14\"\x0f/files/v1/files:\x01*\x12r\n\x03Get\x12(.yandex.cloud.ai.files.v1.GetFileRequest\x1a\x1e.yandex.cloud.ai.files.v1.File\"!\x82\xd3\xe4\x93\x02\x1b\x12\x19/files/v1/files/{file_id}\x12\x83\x01\n\x06GetUrl\x12+.yandex.cloud.ai.files.v1.GetFileUrlRequest\x1a,.yandex.cloud.ai.files.v1.GetFileUrlResponse\"\x1e\x82\xd3\xe4\x93\x02\x18\x12\x16/files/v1/files:getUrl\x12|\n\x06Update\x12+.yandex.cloud.ai.files.v1.UpdateFileRequest\x1a\x1e.yandex.cloud.ai.files.v1.File\"%\x82\xd3\xe4\x93\x02\x1f\x32\x1a/files/v1/update/{file_id}:\x01*\x12\x86\x01\n\x06\x44\x65lete\x12+.yandex.cloud.ai.files.v1.DeleteFileRequest\x1a,.yandex.cloud.ai.files.v1.DeleteFileResponse\"!\x82\xd3\xe4\x93\x02\x1b*\x19/files/v1/files/{file_id}\x12x\n\x04List\x12*.yandex.cloud.ai.files.v1.ListFilesRequest\x1a+.yandex.cloud.ai.files.v1.ListFilesResponse\"\x17\x82\xd3\xe4\x93\x02\x11\x12\x0f/files/v1/filesBb\n\x1cyandex.cloud.api.ai.files.v1ZBgithub.com/yandex-cloud/go-genproto/yandex/cloud/ai/files/v1;filesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.ai.files.v1.file_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\034yandex.cloud.api.ai.files.v1ZBgithub.com/yandex-cloud/go-genproto/yandex/cloud/ai/files/v1;files'
  _CREATEFILEREQUEST_LABELSENTRY._options = None
  _CREATEFILEREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _CREATEFILEREQUEST.fields_by_name['folder_id']._options = None
  _CREATEFILEREQUEST.fields_by_name['folder_id']._serialized_options = b'\350\3071\001'
  _CREATEFILEREQUEST.fields_by_name['content']._options = None
  _CREATEFILEREQUEST.fields_by_name['content']._serialized_options = b'\350\3071\001'
  _GETFILEREQUEST.fields_by_name['file_id']._options = None
  _GETFILEREQUEST.fields_by_name['file_id']._serialized_options = b'\350\3071\001'
  _GETFILEURLREQUEST.fields_by_name['file_id']._options = None
  _GETFILEURLREQUEST.fields_by_name['file_id']._serialized_options = b'\350\3071\001'
  _UPDATEFILEREQUEST_LABELSENTRY._options = None
  _UPDATEFILEREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _UPDATEFILEREQUEST.fields_by_name['file_id']._options = None
  _UPDATEFILEREQUEST.fields_by_name['file_id']._serialized_options = b'\350\3071\001'
  _UPDATEFILEREQUEST.fields_by_name['update_mask']._options = None
  _UPDATEFILEREQUEST.fields_by_name['update_mask']._serialized_options = b'\350\3071\001'
  _DELETEFILEREQUEST.fields_by_name['file_id']._options = None
  _DELETEFILEREQUEST.fields_by_name['file_id']._serialized_options = b'\350\3071\001'
  _LISTFILESREQUEST.fields_by_name['folder_id']._options = None
  _LISTFILESREQUEST.fields_by_name['folder_id']._serialized_options = b'\350\3071\001'
  _FILESERVICE.methods_by_name['Create']._options = None
  _FILESERVICE.methods_by_name['Create']._serialized_options = b'\202\323\344\223\002\024\"\017/files/v1/files:\001*'
  _FILESERVICE.methods_by_name['Get']._options = None
  _FILESERVICE.methods_by_name['Get']._serialized_options = b'\202\323\344\223\002\033\022\031/files/v1/files/{file_id}'
  _FILESERVICE.methods_by_name['GetUrl']._options = None
  _FILESERVICE.methods_by_name['GetUrl']._serialized_options = b'\202\323\344\223\002\030\022\026/files/v1/files:getUrl'
  _FILESERVICE.methods_by_name['Update']._options = None
  _FILESERVICE.methods_by_name['Update']._serialized_options = b'\202\323\344\223\002\0372\032/files/v1/update/{file_id}:\001*'
  _FILESERVICE.methods_by_name['Delete']._options = None
  _FILESERVICE.methods_by_name['Delete']._serialized_options = b'\202\323\344\223\002\033*\031/files/v1/files/{file_id}'
  _FILESERVICE.methods_by_name['List']._options = None
  _FILESERVICE.methods_by_name['List']._serialized_options = b'\202\323\344\223\002\021\022\017/files/v1/files'
  _globals['_CREATEFILEREQUEST']._serialized_start=243
  _globals['_CREATEFILEREQUEST']._serialized_end=553
  _globals['_CREATEFILEREQUEST_LABELSENTRY']._serialized_start=508
  _globals['_CREATEFILEREQUEST_LABELSENTRY']._serialized_end=553
  _globals['_GETFILEREQUEST']._serialized_start=555
  _globals['_GETFILEREQUEST']._serialized_end=594
  _globals['_GETFILEURLREQUEST']._serialized_start=596
  _globals['_GETFILEURLREQUEST']._serialized_end=638
  _globals['_GETFILEURLRESPONSE']._serialized_start=640
  _globals['_GETFILEURLRESPONSE']._serialized_end=673
  _globals['_UPDATEFILEREQUEST']._serialized_start=676
  _globals['_UPDATEFILEREQUEST']._serialized_end=997
  _globals['_UPDATEFILEREQUEST_LABELSENTRY']._serialized_start=508
  _globals['_UPDATEFILEREQUEST_LABELSENTRY']._serialized_end=553
  _globals['_DELETEFILEREQUEST']._serialized_start=999
  _globals['_DELETEFILEREQUEST']._serialized_end=1041
  _globals['_DELETEFILERESPONSE']._serialized_start=1043
  _globals['_DELETEFILERESPONSE']._serialized_end=1063
  _globals['_LISTFILESREQUEST']._serialized_start=1065
  _globals['_LISTFILESREQUEST']._serialized_end=1147
  _globals['_LISTFILESRESPONSE']._serialized_start=1149
  _globals['_LISTFILESRESPONSE']._serialized_end=1240
  _globals['_FILESERVICE']._serialized_start=1243
  _globals['_FILESERVICE']._serialized_end=2006
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.iam.v1.resource_pb2
import yandex.cloud.iam.v1.service_control_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetServiceRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SERVICE_ID_FIELD_NUMBER: builtins.int
    RESOURCE_FIELD_NUMBER: builtins.int
    service_id: builtins.str
    """ID of the Service."""
    @property
    def resource(self) -> yandex.cloud.iam.v1.resource_pb2.Resource:
        """Resource container to get a service information in.

        It is supported only resource-manager.cloud resource container now.
        """

    def __init__(
        self,
        *,
        service_id: builtins.str = ...,
        resource: yandex.cloud.iam.v1.resource_pb2.Resource | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["resource", b"resource"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["resource", b"resource", "service_id", b"service_id"]) -> None: ...

global___GetServiceRequest = GetServiceRequest

@typing.final
class ListServicesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than [page_size],
    the service returns a [ListServicesResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    Default value: 100
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set [page_token]
    to the [ListServicesResponse.next_page_token]
    returned by a previous list request.
    """
    @property
    def resource(self) -> yandex.cloud.iam.v1.resource_pb2.Resource:
        """Resource container to list a services.

        It is supported only resource-manager.cloud resource container now.
        """

    def __init__(
        self,
        *,
        resource: yandex.cloud.iam.v1.resource_pb2.Resource | None = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["resource", b"resource"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["page_size", b"page_size", "page_token", b"page_token", "resource", b"resource"]) -> None: ...

global___ListServicesRequest = ListServicesRequest

@typing.final
class ListServicesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SERVICES_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """This token allows you to get the next page of results for list requests. If the number of results
    is larger than [ListServicesRequest.page_size], use
    the [next_page_token] as the value
    for the [ListServicesRequest.page_token] query parameter
    in the next list request. Each subsequent list request will have its own
    [next_page_token] to continue paging through the results.
    """
    @property
    def services(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.iam.v1.service_control_pb2.Service]:
        """List of Services."""

    def __init__(
        self,
        *,
        services: collections.abc.Iterable[yandex.cloud.iam.v1.service_control_pb2.Service] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "services", b"services"]) -> None: ...

global___ListServicesResponse = ListServicesResponse

@typing.final
class EnableServiceRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SERVICE_ID_FIELD_NUMBER: builtins.int
    RESOURCE_FIELD_NUMBER: builtins.int
    service_id: builtins.str
    """ID of the Service."""
    @property
    def resource(self) -> yandex.cloud.iam.v1.resource_pb2.Resource:
        """Resource container to enable a service in.

        It is supported only resource-manager.cloud resource container now.
        """

    def __init__(
        self,
        *,
        service_id: builtins.str = ...,
        resource: yandex.cloud.iam.v1.resource_pb2.Resource | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["resource", b"resource"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["resource", b"resource", "service_id", b"service_id"]) -> None: ...

global___EnableServiceRequest = EnableServiceRequest

@typing.final
class EnableServiceMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SERVICE_ID_FIELD_NUMBER: builtins.int
    RESOURCE_FIELD_NUMBER: builtins.int
    service_id: builtins.str
    """ID of the Service."""
    @property
    def resource(self) -> yandex.cloud.iam.v1.resource_pb2.Resource:
        """Resource container."""

    def __init__(
        self,
        *,
        service_id: builtins.str = ...,
        resource: yandex.cloud.iam.v1.resource_pb2.Resource | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["resource", b"resource"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["resource", b"resource", "service_id", b"service_id"]) -> None: ...

global___EnableServiceMetadata = EnableServiceMetadata

@typing.final
class DisableServiceRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SERVICE_ID_FIELD_NUMBER: builtins.int
    RESOURCE_FIELD_NUMBER: builtins.int
    service_id: builtins.str
    """ID of the Service."""
    @property
    def resource(self) -> yandex.cloud.iam.v1.resource_pb2.Resource:
        """Resource container to disable a service in.

        It is supported only resource-manager.cloud resource container now.
        """

    def __init__(
        self,
        *,
        service_id: builtins.str = ...,
        resource: yandex.cloud.iam.v1.resource_pb2.Resource | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["resource", b"resource"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["resource", b"resource", "service_id", b"service_id"]) -> None: ...

global___DisableServiceRequest = DisableServiceRequest

@typing.final
class DisableServiceMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SERVICE_ID_FIELD_NUMBER: builtins.int
    RESOURCE_FIELD_NUMBER: builtins.int
    service_id: builtins.str
    """ID of the Service."""
    @property
    def resource(self) -> yandex.cloud.iam.v1.resource_pb2.Resource:
        """Resource container."""

    def __init__(
        self,
        *,
        service_id: builtins.str = ...,
        resource: yandex.cloud.iam.v1.resource_pb2.Resource | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["resource", b"resource"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["resource", b"resource", "service_id", b"service_id"]) -> None: ...

global___DisableServiceMetadata = DisableServiceMetadata

@typing.final
class ResolveServiceAgentRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SERVICE_ID_FIELD_NUMBER: builtins.int
    MICROSERVICE_ID_FIELD_NUMBER: builtins.int
    RESOURCE_FIELD_NUMBER: builtins.int
    service_id: builtins.str
    """ID of the Service."""
    microservice_id: builtins.str
    """ID of the Microservice."""
    @property
    def resource(self) -> yandex.cloud.iam.v1.resource_pb2.Resource:
        """Resource container."""

    def __init__(
        self,
        *,
        service_id: builtins.str = ...,
        microservice_id: builtins.str = ...,
        resource: yandex.cloud.iam.v1.resource_pb2.Resource | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["resource", b"resource"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["microservice_id", b"microservice_id", "resource", b"resource", "service_id", b"service_id"]) -> None: ...

global___ResolveServiceAgentRequest = ResolveServiceAgentRequest



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from yandex.cloud.datasphere.v1 import node_service_pb2 as yandex_dot_cloud_dot_datasphere_dot_v1_dot_node__service__pb2


class NodeServiceStub(object):
    """A set of methods for managing Node resources.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Execute = channel.unary_unary(
                '/yandex.cloud.datasphere.v1.NodeService/Execute',
                request_serializer=yandex_dot_cloud_dot_datasphere_dot_v1_dot_node__service__pb2.NodeExecutionRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_datasphere_dot_v1_dot_node__service__pb2.NodeExecutionResponse.FromString,
                )
        self.ExecuteAlias = channel.unary_unary(
                '/yandex.cloud.datasphere.v1.NodeService/ExecuteAlias',
                request_serializer=yandex_dot_cloud_dot_datasphere_dot_v1_dot_node__service__pb2.AliasExecutionRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_datasphere_dot_v1_dot_node__service__pb2.AliasExecutionResponse.FromString,
                )


class NodeServiceServicer(object):
    """A set of methods for managing Node resources.
    """

    def Execute(self, request, context):
        """Executes deployed Node.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ExecuteAlias(self, request, context):
        """Executes NodeAlias requests.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_NodeServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Execute': grpc.unary_unary_rpc_method_handler(
                    servicer.Execute,
                    request_deserializer=yandex_dot_cloud_dot_datasphere_dot_v1_dot_node__service__pb2.NodeExecutionRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_datasphere_dot_v1_dot_node__service__pb2.NodeExecutionResponse.SerializeToString,
            ),
            'ExecuteAlias': grpc.unary_unary_rpc_method_handler(
                    servicer.ExecuteAlias,
                    request_deserializer=yandex_dot_cloud_dot_datasphere_dot_v1_dot_node__service__pb2.AliasExecutionRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_datasphere_dot_v1_dot_node__service__pb2.AliasExecutionResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'yandex.cloud.datasphere.v1.NodeService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class NodeService(object):
    """A set of methods for managing Node resources.
    """

    @staticmethod
    def Execute(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.datasphere.v1.NodeService/Execute',
            yandex_dot_cloud_dot_datasphere_dot_v1_dot_node__service__pb2.NodeExecutionRequest.SerializeToString,
            yandex_dot_cloud_dot_datasphere_dot_v1_dot_node__service__pb2.NodeExecutionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ExecuteAlias(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.datasphere.v1.NodeService/ExecuteAlias',
            yandex_dot_cloud_dot_datasphere_dot_v1_dot_node__service__pb2.AliasExecutionRequest.SerializeToString,
            yandex_dot_cloud_dot_datasphere_dot_v1_dot_node__service__pb2.AliasExecutionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
